<?php

namespace edu\wisc\doit\uwphps;

/**
 * UseDetailsProvider is an interface defining how to load an {@link UserDetails} and provides constants for
 * supplied request header keys.
 */
abstract class UserDetailsProvider
{

    /** @var bool Flag indicating if headers are passed prefixed with 'HTTP_' */
    protected $httpHeaders;
    
    // Constants representing UW Federated login Shibboleth headers
    const FED_EPPN = "eppn";
    const FED_SPVI = "eduWisconsinSPVI";
    const FED_FULLNAME = "eduWisconsinCommonName";
    const FED_FIRST_NAME = "eduWisconsinGivenName";
    const FED_LAST_NAME = "eduWisconsinSurname";
    const FED_EMAIL = "eduWisconsinEmailAddress";

    // Generic and/or UWMSN constants
    const SHIB_SESSION_ID = 'Shib-Session-Id';
    const SHIB_SESSION_ID_HTTP = 'HTTP_SHIB_SESSION_ID';
    const UDDS = "udds";
    const SOURCE = "source";
    const ISIS_EMPLID = "isisEmplid";

    /**
     * UserDetailsProvider constructor.
     * @param $http
     */
    public function __construct($http = true)
    {
        $this->http = $http;
    }

    /**
     * Map Shibboleth header values to an associative array.
     *
     * @return UserDetails
     */
    abstract public function loadUser();


    /**
     * Map a Shibboleth attribute to its associated HTTP header name.
     *
     * @param string $attribute attribute to map
     * @return string Shibboleth attribute name mapped to its equivalent HTTP header name
     */
    protected function mapAttribute($attribute)
    {
        return 'HTTP_' . strtoupper($attribute);
    }

}
