<?php

namespace edu\wisc\doit\uwphps\preauth;

use edu\wisc\doit\uwphps\UWUserDetails;
use edu\wisc\doit\uwphps\UserDetailsProvider;

/**
 * FederatedPreauthUserDetailsProvider is an implementation of {@link UserDetailsProvider} for loading users
 * authenticated with UW-System Federated login.
 *
 * {@see PreauthUserDetailsProvider} for loading users authenticated through UW-Madison login.
 */
class FederatedPreauthUserDetailsProvider extends UserDetailsProvider
{

    /**
     * {@inheritdoc}
     */
    public function loadUser()
    {
        // Return null if no Shib session is found
        if ($this->httpHeaders && !getenv(FederatedPreauthUserDetailsProvider::SHIB_SESSION_ID_HTTP) ||
            !$this->httpHeaders && !getenv(FederatedPreauthUserDetailsProvider::SHIB_SESSION_ID)) {
            return null;
        }

        if ($this->httpHeaders) {
            $userDetails = new UWUserDetails(
                getenv($this->mapAttribute(UserDetailsProvider::FED_EPPN)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_SPVI)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_FULLNAME)),
                getenv($this->mapAttribute(UserDetailsProvider::UDDS)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_EMAIL)),
                getenv($this->mapAttribute(UserDetailsProvider::SOURCE)),
                getenv($this->mapAttribute(UserDetailsProvider::ISIS_EMPLID)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_FIRST_NAME)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_LAST_NAME))
            );
        } else {
            $userDetails = new UWUserDetails(
                getenv(UserDetailsProvider::FED_EPPN),
                getenv(UserDetailsProvider::FED_SPVI),
                getenv(UserDetailsProvider::FED_FULLNAME),
                getenv(UserDetailsProvider::UDDS),
                getenv(UserDetailsProvider::FED_EMAIL),
                getenv(UserDetailsProvider::SOURCE),
                getenv(UserDetailsProvider::ISIS_EMPLID),
                getenv(UserDetailsProvider::FED_FIRST_NAME),
                getenv(UserDetailsProvider::FED_LAST_NAME)
            );
        }

        return $userDetails;
    }

}
