<?php

use edu\wisc\doit\uwphps\UserDetailsProvider;
use edu\wisc\doit\uwphps\preauth\FederatedPreauthUserDetailsProvider;

/**
 * Tests for {@link FederatedPreauthUserDetailsProvider}.
 */
class HTTPFederatedPreauthUserDetailsProviderTest extends \PHPUnit_Framework_TestCase
{

    /** @var array */
    private $attributes;

    /** @var UserDetailsProvider */
    private $userProvider;

    /**
     * Populate putenv with Shib attributes to simulate a logged in user
     */
    protected function setUp()
    {
        parent::setUp();
        $jsonString = file_get_contents(__DIR__ . "/../../../resources/testuser_http.json");
        if ($jsonString === false) {
            return null;
        }

        $this->attributes = json_decode($jsonString, true);
        $this->userProvider = new FederatedPreauthUserDetailsProvider();

        putenv($this->mapAttribute(UserDetailsProvider::FED_EPPN) . '=' . $this->attributes[$this->mapAttribute(UserDetailsProvider::FED_EPPN)]);
        putenv($this->mapAttribute(UserDetailsProvider::FED_SPVI) . '=' . $this->attributes[$this->mapAttribute(UserDetailsProvider::FED_SPVI)]);
        putenv($this->mapAttribute(UserDetailsProvider::FED_FULLNAME) . '=' . $this->attributes[$this->mapAttribute(UserDetailsProvider::FED_FULLNAME)]);
        putenv($this->mapAttribute(UserDetailsProvider::FED_FIRST_NAME) . '=' . $this->attributes[$this->mapAttribute(UserDetailsProvider::FED_FIRST_NAME)]);
        putenv($this->mapAttribute(UserDetailsProvider::FED_LAST_NAME) . '=' . $this->attributes[$this->mapAttribute(UserDetailsProvider::FED_LAST_NAME)]);
        putenv($this->mapAttribute(UserDetailsProvider::UDDS) . '=' . implode(",", $this->attributes[$this->mapAttribute(UserDetailsProvider::UDDS)]));
        putenv($this->mapAttribute(UserDetailsProvider::FED_EMAIL) . '=' . $this->attributes[$this->mapAttribute(UserDetailsProvider::FED_EMAIL)]);
        putenv($this->mapAttribute(UserDetailsProvider::SOURCE) . '=' . $this->attributes[$this->mapAttribute(UserDetailsProvider::SOURCE)]);
        putenv($this->mapAttribute(UserDetailsProvider::ISIS_EMPLID) . '=' . $this->attributes[$this->mapAttribute(UserDetailsProvider::ISIS_EMPLID)]);
        putenv(UserDetailsProvider::SHIB_SESSION_ID_HTTP  . '=' . $this->attributes[UserDetailsProvider::SHIB_SESSION_ID_HTTP]);
    }

    public function testLoadUser()
    {
        $user = $this->userProvider->loadUser();
        $this->assertNotNull($user);
        $this->assertEquals("bbadger@wisc.edu", $user->getEppn());
        $this->assertEquals("UW123A456", $user->getPvi());
        $this->assertEquals("BUCKINGHAM BADGER", $user->getFullName());
        $this->assertEquals("bucky.badger@wisc.edu", $user->getEmailAddress());
        $this->assertEquals("a_source", $user->getSource());
        $this->assertEquals("123456789", $user->getIsisEmplid());
        $this->assertEquals("BUCKINGHAM", $user->getFirstName());
        $this->assertEquals("BADGER", $user->getLastName());
    }

    public function testLoadUserWithNoEPPN()
    {
        // Clear Shib session ID to simulate no session
        putenv(UserDetailsProvider::SHIB_SESSION_ID_HTTP);
        $user = $this->userProvider->loadUser();
        $this->assertNull($user);
    }

    public function testLoadUserWithNoEmail()
    {
        // Clear email to simulate no email
        putenv('HTTP_' . strtoupper(UserDetailsProvider::FED_EMAIL));
        $user = $this->userProvider->loadUser();
        $this->assertFalse($user->getEmailAddress());
    }

    private function mapAttribute($attribute)
    {
        return 'HTTP_' . strtoupper($attribute);
    }

}
